@@ -129,14 +129,16 @@ def handle_script_upload(s3client, file_location, destination_key, glue_script_b
     Uploads the Glue Job script to the S3 bucket, and creates the necessary environment bucket if it doesn't exist.
     """
 
-    glue_script_bucket_sanitized = glue_script_bucket.replace('_', '-')
+    glue_script_bucket_sanitized = glue_script_bucket.replace("_", "-")
 
     try:
         s3client.create_bucket(Bucket=glue_script_bucket_sanitized)
     except ClientError as e:
         pass
 
-    response = s3client.upload_file(file_location, glue_script_bucket_sanitized, destination_key)
+    response = s3client.upload_file(
+        file_location, glue_script_bucket_sanitized, destination_key
+    )
 
     return response
 
@@ -151,7 +153,7 @@ def handle_trigger(
 
     if new_trigger:
         response = glueclient.create_trigger(
-            Name=trigger_name, Type=trigger_type, Actions={"JobName": job_name}
+            Name=trigger_name, Type=trigger_type, Actions=[{"JobName": job_name}]
         )
 
     response = glueclient.update_trigger(
